@@ -1,3 +1,4 @@
+import os.path
 import yaml
 
 class ConfigClass:
@@ -9,6 +10,7 @@ class ConfigClass:
     verification_expiration = 86400 * 30
     verification_update_frequency = 3600
     oldest_event = 31536000
+    redirect_homepage = ''
 
     def __init__(self):
         self.gunicorn = {}
@@ -53,13 +55,19 @@ class ConfigClass:
         s += ')'
         return s
 
-    def load(self, filename):
+    def load(self, filename=None):
+        filename = filename or os.path.abspath(os.path.join(os.path.dirname(__file__), '../config/config.yaml'))
         with open(filename, 'r') as fp:
             conf = yaml.load(fp, yaml.FullLoader)
 
         for k, v in conf.items():
             setattr(self, k, v)
 
+        proc_name = self.gunicorn.get('proc_name', '')
+        if proc_name:
+            import multiprocessing
+            multiprocessing.current_process().name = proc_name
+
     def __getattr__(self, attrname):
         return None
 
